@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2012. All Rights Reserved.
rem  
rem  Note to U.S. Government Users Restricted Rights:  
rem  Use, duplication or disclosure restricted by GSA ADP Schedule 
rem  Contract with IBM Corp. 
rem  *******************************************************************************


REM #############################################################
REM #
REM # dm_upgrade.bat スクリプト・パラメーターとそのデフォルト
REM # 値に対応する環境変数の定義
REM #
REM #===========================================================
REM #
REM # このファイルは、dm_upgrade.bat スクリプトの実行の開始時に
REM # 読み取られます。これは、定義済みのデフォルト値がある
REM # 有効なパラメーターごとに 1 つの環境変数を設定します。
REM #
REM # ユーザーは、デフォルト値を変更して dm_upgrade.bat スクリ
REM # プトを独自の値で起動することもできます。そうすれば、コマン
REM # ド行でパラメーターとそれに対応する値を手動で入力する必要
REM # はありません。
REM #
REM # 警告:
REM # すべてのアプリケーションにすべての変数を設定する必要は
REM # ありません。値を変更する前に、それぞれのコメントを
REM # 注意深くお読みください。
REM #
REM #############################################################

rem パラメーター: -oldApplicationHome
rem 使用法: -oldApplicationHome <ディレクトリー・パス>
rem 説明:
rem 	旧インストール済み環境でのアプリケーション・ホーム・ディレクトリーの絶対パス。
rem デフォルト:
rem 	<なし>
rem 制約:
rem  - これは必須パラメーターです。
rem  - <ディレクトリー・パス> は、'server\conf' で終わる既存のディレクトリーでなければなりません。
rem    例: D:\Jazz\IBM\JazzInstallDir\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem パラメーター: -applicationContextRoot
rem 使用法: -applicationContextRoot <ルート>
rem 説明:
rem 	アプリケーション・コンテキスト・ルート。
rem デフォルト:
rem 	dm
rem 制約:
rem  - <ルート> は有効な単一のディレクトリー名 (前にスラッシュがないもの) でなければなりません。
rem
set APPLICATION_CONTEXT_ROOT=dm

rem パラメーター: -oldApplicationVersion
rem 使用法: -oldApplicationVersion <バージョン>
rem 説明:
rem 	アップグレードする DM バージョン。デフォルトでは、古いアプリケーションに対して
rem     repotools -version を実行する操作でこの値が判別されます。
rem デフォルト:
rem 	<なし>
rem 制約:
rem  - 完全なバージョン・ストリング
rem    (4.0 など) にしてください
rem
set OLD_APPLICATION_VERSION=

rem パラメーター: -newApplicationHome
rem 使用法: -newApplicationHome <ディレクトリー・パス>
rem 説明:
rem 	新規インストール済み環境でのアプリケーション・ホーム・ディレクトリーのパス。
rem デフォルト:
rem 	<現在のディレクトリー>\conf
rem 制約:
rem  - これは必須パラメーターです。
rem  - <ディレクトリー・パス> は、'server\conf' で終わる既存のディレクトリーでなければなりません。
rem    例: D:\Jazz\IBM\JazzInstallDir\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem パラメーター: -updateTomcatFiles
rem 使用法: -updateTomcatFiles <yes | no>
rem 説明:
rem 	Tomcat 構成ファイルを更新するかどうか。
rem デフォルト:
rem 	yes
rem 制約:
rem  - 有効値は「yes」および「no」のみです。
rem
set UPDATE_TOMCAT_FILES=yes

rem パラメーター: -oldApplicationTomcatHome
rem 使用法: -oldApplicationTomcatHome <ディレクトリー・パス>
rem 説明:
rem 	旧インストール済み環境での Tomcat ルート・ディレクトリーの絶対パス。
rem デフォルト:
rem 	<なし>
rem 制約:
rem  - 既存のディレクトリーでなければなりません。
rem
set OLD_APP_TOMCAT_HOME=

rem パラメーター: -newApplicationTomcatHome
rem 使用法: -newApplicationTomcatHome <ディレクトリー・パス>
rem 説明:
rem 	新規インストール済み環境でのアプリケーション Tomcat ルート・ディレクトリーのパス。
rem デフォルト:
rem 	<なし>
rem
set NEW_APP_TOMCAT_HOME=

rem パラメーター: -newJTSHome
rem 使用法: -newJTSHome <ディレクトリー・パス>
rem 説明:
rem 	新規インストール済み環境で使用する JTS の JTS サーバー構成ディレクトリーのパス。
rem デフォルト:
rem 	新規のアプリケーション・ホーム・ディレクトリー
rem 制約:
rem  - <ディレクトリー・パス> は、「server\conf」で終わる既存のディレクトリーでなければなりません。
rem
set NEW_JTS_HOME=

rem パラメーター: -jtsContextRoot
rem 使用法: -jtsContextRoot <ルート>
rem 説明:
rem 	JTS サーバーのコンテキスト・ルート。
rem デフォルト:
rem 	jts
rem 制約:
rem  - <ルート> は有効な単一のディレクトリー名 (前にスラッシュがないもの) でなければなりません。
rem
set JTS_CONTEXT_ROOT=jts

rem パラメーター: -noPrompt
rem 使用法: -noPrompt
rem 説明:
rem 	表を作成または変更する前にプロンプトを出しません。
rem デフォルト:
rem 	<なし>
rem 制約:
rem  - 有効値は空または「noPrompt」のみです。
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem パラメーター: -noVerify
rem 使用法: -noVerify
rem 説明:
rem 	teamserver.properties ファイルの検査を実行しません。
rem デフォルト:
rem 	<なし>
rem 制約:
rem  - 有効値は空または「noVerify」のみです。
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem パラメーター: -overwrite
rem 使用法: -overwrite
rem 説明:
rem 	既存のファイルをすべて上書きするかどうか。
rem デフォルト:
rem 	no
rem 制約:
rem  - 有効値は空または「overwrite=yes」のみです。
rem
rem set OVERWRITE=overwrite=yes
set OVERWRITE=

rem パラメーター: -noStepPrompt
rem 使用法: -noStepPrompt
rem 説明:
rem 	ステップを実行する前にプロンプトを出しません。
rem デフォルト:
rem 	false
rem 制約:
rem  - 有効値は「true」または「false」のみです。
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false
