@echo off
rem *******************************************************************************
rem  Materiais Licenciados - Propriedade da IBM
rem  (c) Copyright IBM Corporation 2012. Todos os Direitos Reservados.
rem
rem  Nota sobre Direitos Restritos para Usuários do Governo dos Estados Unidos:
rem  Uso, duplicação ou divulgação restritos pelo documento GSA ADP Schedule
rem  Contract com a IBM Corp.
rem  *******************************************************************************


REM #############################################################
REM #
REM # Defina as variáveis de ambiente correspondentes aos
REM # parâmetros de dm_upgrade.bat e seus valores padrão
REM #
REM #===========================================================
REM #
REM # Este arquivo é lido no início da execução do script
REM # dm_upgrade.bat. Ele configura uma variável de ambiente
REM # por parâmetro válido com um valor padrão predefinido.
REM #
REM # Os usuários podem desejar modificar o valor padrão, a fim de
REM # ativar o script dm_upgrade.bat com seus próprios valores
REM # sem ter de inserir manualmente o parâmetro e seu valor
REM # correspondente na linha de comandos.
REM #
REM # AVISO:
REM # Nem todas as variáveis precisam ser configuradas para todo
REM # aplicativo.  Leia cada comentário cuidadosamente antes de modificar
REM # o valor.
REM #
REM #############################################################

rem Parâmetro: -oldApplicationHome
rem Uso: -oldApplicationHome <dir path>
rem Descrição:
rem 	Caminho completo para o diretório inicial do aplicativo na instalação antiga.
rem Padrão:
rem 	<none>
rem Restrições:
rem  - este é um parâmetro obrigatório
rem  - <dir path> deve ser um diretório existente terminado com 'server\conf'
rem    exemplo: D:\Jazz\IBM\JazzInstallDir\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Parâmetro: -applicationContextRoot
rem Uso: -applicationContextRoot <root>
rem Descrição:
rem 	Raiz de contexto de aplicativos.
rem Padrão:
rem 	dm
rem Restrições:
rem  - <root> deve ser um único nome de diretório válido (isto é, sem barra à esquerda)
rem
set APPLICATION_CONTEXT_ROOT=dm

rem Parâmetro: -oldApplicationVersion
rem Uso: -oldApplicationVersion <version>
rem Descrição:
rem 	A versão do DM que está sendo atualizada.  Por padrão, isso é determinado
rem     ao executar repotools -version com relação ao aplicativo anterior.
rem Padrão:
rem 	<none>
rem Restrições:
rem  - deve ser uma sequência de versões completa
rem    exemplo: 4.0
rem
set OLD_APPLICATION_VERSION=

rem Parâmetro: -newApplicationHome
rem Uso: -newApplicationHome <dir path>
rem Descrição:
rem 	Caminho para o diretório inicial do Aplicativo na nova instalação.
rem Padrão:
rem 	<currentDir>/conf
rem Restrições:
rem  - Este é um parâmetro obrigatório
rem  - <dir path> deve ser um diretório existente terminado com 'server\conf'
rem    exemplo: D:\Jazz\IBM\JazzInstallDir\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Parâmetro: -updateTomcatFiles
rem Uso: -updateTomcatFiles <yes | no>
rem Descrição:
rem 	Se os arquivos de configuração tomcat devem ser atualizados.
rem Padrão:
rem 	yes
rem Restrições:
rem  - Os únicos valores válidos são 'yes' e 'no'
rem
set UPDATE_TOMCAT_FILES=yes

rem Parâmetro: -oldApplicationTomcatHome
rem Uso: -oldApplicationTomcatHome <dir path>
rem Descrição:
rem 	Caminho completo para o diretório-raiz Tomcat na instalação antiga.
rem Padrão:
rem 	<none>
rem Restrições:
rem  - Deve ser um diretório existente
rem
set OLD_APP_TOMCAT_HOME=

rem Parâmetro: -newApplicationTomcatHome
rem Uso: -newApplicationTomcatHome <dir path>
rem Descrição:
rem 	Caminho para o diretório-raiz Tomcat do Aplicativo na nova instalação.
rem Padrão:
rem 	<none>
rem
set NEW_APP_TOMCAT_HOME=

rem Parâmetro: -newJTSHome
rem Uso: -newJTSHome <dir path>
rem Descrição:
rem 	Caminho para o diretório de configuração do servidor do JTS que será usado pela nova instalação.
rem Padrão:
rem 	O novo diretório inicial do aplicativo
rem Restrições:
rem  - <dir path> deve ser um diretório existente finalizando com 'server\conf'
rem
set NEW_JTS_HOME=

rem Parâmetro: -jtsContextRoot
rem Uso: -jtsContextRoot <root>
rem Descrição:
rem 	Raiz de contexto do servidor do JTS.
rem Padrão:
rem 	jts
rem Restrições:
rem  - <root> deve ser um nome único de diretório válido (isto é, nenhuma barra à esquerda)
rem
set JTS_CONTEXT_ROOT=jts

rem Parâmetro: -noPrompt
rem Uso: -noPrompt
rem Descrição:
rem 	Não avise antes de criar ou modificar as tabelas
rem Padrão:
rem 	<none>
rem Restrições:
rem  - Os únicos valores válidos são vazio ou 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Parâmetro: -noVerify
rem Uso: -noVerify
rem Descrição:
rem  Não execute a verificação de arquivos teamserver.properties.
rem Padrão:
rem 	<none>
rem Restrições:
rem  - Os únicos valores válidos são vazio ou 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Parâmetro: -overwrite
rem Uso: -overwrite
rem Descrição:
rem 	Se deve-se sobrescrever qualquer arquivo existente.
rem Padrão:
rem 	no
rem Restrições:
rem  - Os únicos valores válidos são vazio ou 'overwrite=yes'
rem
rem set OVERWRITE=overwrite=yes
set OVERWRITE=

rem Parâmetro: -noStepPrompt
rem Uso: -noStepPrompt
rem Descrição:
rem 	Não avisar antes de executar uma etapa.
rem Padrão:
rem 	false
rem Restrições:
rem  - Os únicos valores válidos são 'true' e 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false
