@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2012. All Rights Reserved.
rem  
rem  Note to U.S. Government Users Restricted Rights:  
rem  Use, duplication or disclosure restricted by GSA ADP Schedule 
rem  Contract with IBM Corp. 
rem  *******************************************************************************


REM #############################################################
REM #
REM # 定義對應於 dm_upgrade.bat Script 參數
REM # 及其預設值的環境變數
REM #
REM #===========================================================
REM #
REM # 開始執行 dm_upgrade.bat Script 時，
REM # 會讀取這個檔案。這個檔案會為每一個有效的參數，預
REM # 先定義一個預設值，來設定各個環境變數。
REM #
REM # 使用者可能想要修改預設值，
REM # 從而以其自己的值來啟動
REM # dm_upgrade.bat Script，而無需
REM # 手動在指令行中輸入參數及其對應的值。

REM #
REM # 警告：
REM # 對每一個應用程式來說，並非所有的變數
REM # 都需要設定。修改值之前，請仔細閱讀每
REM # 一則註解。
REM #
REM #############################################################

rem 參數：-oldApplicationHome
rem 用法：-oldApplicationHome <dir path>
rem 說明：
rem 	舊安裝中應用程式起始目錄的完整路徑。
rem 預設值：
rem 	<無>
rem 限制：
rem  - 這是必要參數
rem  - <dir path> 必須是現有目錄，且以 'server\conf' 結尾
rem    例如，D:\Jazz\IBM\JazzInstallDir\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem 參數：-applicationContextRoot
rem 用法：-applicationContextRoot <root>
rem 說明：
rem 	應用程式環境定義根目錄。
rem 預設值：
rem 	dm
rem 限制：
rem  - <root> 必須是有效的目錄單一名稱（即，沒有前導斜線）
rem
set APPLICATION_CONTEXT_ROOT=dm

rem 參數：-oldApplicationVersion
rem 用法：-oldApplicationVersion <version>
rem 說明：
rem 	正在升級的 DM 版本。依預設，這是透過對舊應用程式
rem     執行 repotools -version 來判斷。
rem 預設值：
rem 	<無>
rem 限制：
rem  -  應該是完整的版本字串
rem    例如，4.0
rem
set OLD_APPLICATION_VERSION=

rem 參數：-newApplicationHome
rem 用法：-newApplicationHome <dir path>
rem 說明：
rem 	新安裝中應用程式起始目錄的路徑。
rem 預設值：
rem 	<currentDir>/conf
rem 限制：
rem  - 這是必要參數
rem  - <dir path> 必須是現有目錄，且以 'server\conf' 結尾
rem    例如，D:\Jazz\IBM\JazzInstallDir\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem 參數：-updateTomcatFiles
rem 用法：-updateTomcatFiles <yes | no>
rem 說明：
rem 	是否更新 Tomcat 配置檔？
rem 預設值：
rem 	yes
rem 限制：
rem  - 唯一有效值是 'yes' 和 'no'
rem
set UPDATE_TOMCAT_FILES=yes

rem 參數：-oldApplicationTomcatHome
rem 用法：-oldApplicationTomcatHome <dir path>
rem 說明：
rem 	舊安裝中 Tomcat 根目錄的完整路徑。
rem 預設值：
rem 	<無>
rem 限制：
rem  - 必須是現有目錄
rem
set OLD_APP_TOMCAT_HOME=

rem 參數：-newApplicationTomcatHome
rem 用法：-newApplicationTomcatHome <dir path>
rem 說明：
rem 	新安裝中應用程式 Tomcat 根目錄的路徑。
rem 預設值：
rem 	<無>
rem
set NEW_APP_TOMCAT_HOME=

rem 參數：-newJTSHome
rem 用法：-newJTSHome <dir path>
rem 說明：
rem 	新安裝將使用之 JTS 的 JTS 伺服器配置目錄路徑。
rem 預設值：
rem 	新的應用程式起始目錄
rem 限制：
rem  - <dir path> 必須是現有目錄，且結尾是 'server\conf'
rem
set NEW_JTS_HOME=

rem 參數：-jtsContextRoot
rem 用法：-jtsContextRoot <root>
rem 說明：
rem 	JTS 伺服器的環境定義根目錄。
rem 預設值：
rem 	jts
rem 限制：
rem  - <root> 必須是有效的目錄單一名稱（亦即，沒有前導斜線） 
rem
set JTS_CONTEXT_ROOT=jts

rem 參數：-noPrompt
rem 用法：-noPrompt
rem 說明：
rem 	在開始建立或修改表格之前不先提示
rem 預設值：
rem 	<無>
rem 限制：
rem  - 唯一的有效值是空的或 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem 參數：-noVerify
rem 用法：-noVerify
rem 說明：
rem 	不執行 teamserver.properties 檔驗證。
rem 預設值：
rem 	<無>
rem 限制：
rem  - 唯一的有效值是空的或 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem 參數：-overwrite
rem 用法：-overwrite
rem 說明：
rem 	是否改寫任何現有的檔案？
rem 預設值：
rem 	no
rem 限制：
rem  - 唯一的有效值是空的或 'overwrite=yes'
rem
rem set OVERWRITE=overwrite=yes
set OVERWRITE=

rem 參數：-noStepPrompt
rem 用法：-noStepPrompt
rem 說明：
rem 	在開始執行步驟之前不先提示。
rem 預設值：
rem 	false
rem 限制：
rem  - 唯一的有效值是 'true' 或 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false
